import router from './routers'
import store from '@/store'
import Config from '@/settings'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css'// progress bar style
import { getToken } from '@/utils/auth' // getToken from cookie
import { buildMenus } from '@/api/system/menu'
import { filterAsyncRouter } from '@/store/modules/permission'

NProgress.configure({ showSpinner: false })// NProgress Configuration

const whiteList = ['/login', '/nologinShow']// no redirect whitelist

router.beforeEach((to, from, next) => {
  if (to.meta.title) {
    document.title = to.meta.title + ' - ' + Config.title
  }
  if (document.querySelector('#sto')) {
    document.getElementsByTagName('head')[0].removeChild(document.querySelector('#sto'))
    const linkDom = document.createElement('link')
    linkDom.rel = 'stylesheet'
    linkDom.href = 'rep1.css'
    linkDom.id = 'sto1'
    document.getElementsByTagName('head')[0].appendChild(linkDom)
  }
  NProgress.start()
  if (getToken()) {
    // 已登录且要跳转的页面是登录页
    if (to.path === '/login') {
      next({ path: '/' })
      NProgress.done()
    } else {
      if (store.getters.roles.length === 0) { // 判断当前用户是否已拉取完user_info信息
        store.dispatch('GetInfo').then(() => { // 拉取user_info
          // 动态路由，拉取菜单
          loadMenus(next, to)
        }).catch(() => {
          store.dispatch('LogOut').then(() => {
            location.reload() // 为了重新实例化vue-router对象 避免bug
          })
        })
      // 登录时未拉取 菜单，在此处拉取
      } else if (store.getters.loadMenus) {
        // 修改成false，防止死循环
        store.dispatch('updateLoadMenus')
        loadMenus(next, to)
      } else {
        next()
      }
    }
  } else {
    /* has no token*/
    if (whiteList.indexOf(to.path) !== -1) { // 在免登录白名单，直接进入
      next()
    } else {
      next(`/login?redirect=${to.fullPath}`) // 否则全部重定向到登录页
      NProgress.done()
    }
  }
})

export const loadMenus = (next, to) => {
  buildMenus().then(res => {
    const sdata = JSON.parse(JSON.stringify(res))
    const rdata = JSON.parse(JSON.stringify(res))
    const sidebarRoutes = filterAsyncRouter(sdata)
    console.log(sdata, 'sdata sdata sdata sdata')
    // sdata[0].children[6].children = [
    //   {
    //     alwaysShow: null,
    //     component: null,
    //     hidden: false,
    //     meta: {
    //       icon: 'deploy',
    //       noCache: true,
    //       title: '编辑企业信息'
    //     },
    //     name: '编辑企业信息',
    //     path: 'changeinfo'
    //   },
    //   {
    //     alwaysShow: null,
    //     component: null,
    //     hidden: false,
    //     meta: {
    //       icon: 'deploy',
    //       noCache: true,
    //       title: '新增企业信息'
    //     },
    //     name: '新增企业信息',
    //     path: 'addinfo'
    //   }
    // ]
    // sdata[1].children[2].children = [
    //   {
    //     alwaysShow: null,
    //     component: null,
    //     hidden: false,
    //     meta: {
    //       icon: 'deploy',
    //       noCache: true,
    //       title: '隐患管理'
    //     },
    //     name: '隐患管理',
    //     path: 'index'
    //   },
    //   {
    //     alwaysShow: null,
    //     component: null,
    //     hidden: false,
    //     meta: {
    //       icon: 'deploy',
    //       noCache: true,
    //       title: '隐患关键词'
    //     },
    //     name: '隐患关键词',
    //     path: 'vocabulary'
    //   }
    // ]
    // sdata[2].children[5].children = [
    //   {
    //     alwaysShow: null,
    //     component: null,
    //     hidden: false,
    //     meta: {
    //       icon: 'deploy',
    //       noCache: true,
    //       title: '新增分类'
    //     },
    //     name: '新增分类',
    //     path: 'addtype'
    //   },
    //   {
    //     alwaysShow: null,
    //     component: null,
    //     hidden: false,
    //     meta: {
    //       icon: 'deploy',
    //       noCache: true,
    //       title: '课程管理'
    //     },
    //     name: '课程管理',
    //     path: 'course'
    //   }
    // ]
    const rewriteRoutes = filterAsyncRouter(rdata, false, true)
    rewriteRoutes.push({ path: '*', redirect: '/404', hidden: true })
    console.log(sidebarRoutes, 'sidebarRoutes, sidebarRoutes, sidebarRoutes')
    store.dispatch('GenerateRoutes', rewriteRoutes).then(() => { // 存储路由
      router.addRoutes(rewriteRoutes) // 动态添加可访问路由表
      next({ ...to, replace: true })
    })
    store.dispatch('SetSidebarRouters', sidebarRoutes)
  })
}

router.afterEach(() => {
  NProgress.done() // finish progress bar
})
